@@ -16,6 +16,11 @@ BinomSkew <- function(){
   #Normal Approximation to Binomial (need n*p big enough)
   #Number of trials fixed.  You can vary p.  x-axis scale stays same.
   
+  if (!("manipulate"  %in% .packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+                      "in order to run this function.")))
+  }
+  
   manipulate(
     p=slider(0.01,0.99,step=0.01,initial=0.01,label="Success Chance p"),
     norm=checkbox(FALSE,"Show Normal Curve"),
